FlipperNetworkPlugin class

Inheritance

Constructors

FlipperNetworkPlugin({dynamic useHttpOverrides = true, bool filter(HttpClientRequest request)?})

Properties

filter ↔ bool Function(HttpClientRequest request)?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getId() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportRequest(RequestInfo requestInfo) → void
reportResponse(ResponseInfo responseInfo) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

ID → const String