ResponseInfo class

Constructors

ResponseInfo({String? requestId, int? timeStamp, int? statusCode, String? statusReason, Map<String, dynamic>? headers, dynamic body})

Properties

body ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, dynamic>?
getter/setter pair
requestId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode ↔ int?
getter/setter pair
statusReason ↔ String?
getter/setter pair
timeStamp ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited